Network information extraction
==============================

.. toctree::
   :maxdepth: 1

   simulation
   pattern_generation
   dont_cares
   cut_enumeration
   reconv_cut
   extract_linear
   extract_adders